==> front-end-mock-1.0.5.tgz: package/lib/mock-server.js <==
const http = require('http')
const cors = require('kcors')
const Koa = require('koa')
const app = new Koa()
const views = require('koa-views')
const router = require('koa-router')()
const path = require('path')
const bsConfigPath = path.resolve('frontEndMock')
const ip = require("ip");
console.dir(ip.address());
var mockData, port = 3003

try {
    mockData = require(bsConfigPath);
} catch (err) {
    if (err.code && err.code === 'MODULE_NOT_FOUND') {
        logMissingConfigFile();
    } else {
        throw (err);
    }
}

function logMissingConfigFile() {
    console.info('Did not detect a frontEndMock.json or frontEndMock.js file. Please check it in your root direction...')
}

// 允许跨域
app.use(cors());
app.use(views(__dirname + '/views', {
    extension: 'pug'
}))

router.get('/', async(ctx, next) => {
    await ctx.render('index', {
        title: 'Welcome to front-end-mock!'
    })
})


// 生成路由函数
function createRouter(index) {
    router.all(mockData.routers[index].routerName, async(ctx, next) => {
        ctx.body = mockData.routers[index].data.msg
    })
}

// 生成路由
if (mockData && mockData.routers && mockData.routers.length > 0) {
    for (let i = 0; i < mockData.routers.length; i++) {
        createRouter(i);
    }
} else {
    console.info('Cannot findfrontEndMock or the routers is empty');
}

// 生成新的端口
if (mockData && mockData.port) {
    port = mockData.port;
}

// routes
app.use(router.routes(), router.allowedMethods())

var server = http.createServer(app.callback());

console.info(` sever on ${ip.address()} : ${port}`);
server.listen(port);

==> front-end-mock-1.0.6.tgz: package/lib/mock-server.js <==
const http = require('http')
const cors = require('kcors')
const Koa = require('koa')
const app = new Koa()
const views = require('koa-views')
const router = require('koa-router')()
const path = require('path')
const bsConfigPath = path.resolve('frontEndMock')
const ip = require("ip");
console.dir(ip.address());
var mockData, port = 3003

try {
    mockData = require(bsConfigPath);
} catch (err) {
    if (err.code && err.code === 'MODULE_NOT_FOUND') {
        logMissingConfigFile();
    } else {
        throw (err);
    }
}

function logMissingConfigFile() {
    console.info('Did not detect a frontEndMock.json or frontEndMock.js file. Please check it in your root direction...')
}

// 允许跨域
app.use(cors());
app.use(views(__dirname + '/views', {
    extension: 'pug'
}))

router.get('/', async(ctx, next) => {
    await ctx.render('index', {
        title: 'Welcome to front-end-mock!'
    })
})


// 生成路由函数
function createRouter(index) {
    router.all(mockData.routers[index].routerName, async(ctx, next) => {
        ctx.body = mockData.routers[index].data
    })
}

// 生成路由
if (mockData && mockData.routers && mockData.routers.length > 0) {
    for (let i = 0; i < mockData.routers.length; i++) {
        createRouter(i);
    }
} else {
    console.info('Cannot findfrontEndMock or the routers is empty');
}

// 生成新的端口
if (mockData && mockData.port) {
    port = mockData.port;
}

// routes
app.use(router.routes(), router.allowedMethods())

var server = http.createServer(app.callback());

console.info(` sever on ${ip.address()} : ${port}`);
server.listen(port);
